@@ -2,12 +2,13 @@
 
 __author__ = """Kyle Kelley"""
 __email__ = 'rgbkrk@gmail.com'
-__version__ = '0.1.7'
+__version__ = '0.2.0'
 
 
 # Export Markdown from display
 
 from .display import Markdown
 from .messaging import ai, assistant, human, narrate, system, user
+from .murkrow import Murkrow
 
-__all__ = ["Markdown", "human", "ai", "narrate", "system", "user", "assistant"]
+__all__ = ["Markdown", "human", "ai", "narrate", "system", "user", "assistant", "Murkrow"]
